<?php

class HotelesFotosController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column1';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			array(
                'ext.starship.RestfullYii.filters.ERestFilter + 
                REST.GET, REST.PUT, REST.POST, REST.DELETE'
            ),
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow', 'actions'=>array('REST.GET', 'REST.PUT', 'REST.POST', 'REST.DELETE'),
				'users'=>array('@'),
			),
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view'),
				'users'=>array('@'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update','GeneratePdf','GenerateExcel','hotelesFotos'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin','delete'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	public function actions()
	{
        return array('REST.'=>'ext.starship.RestfullYii.actions.ERestActionProvider',);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	public function actionHotelesFotos(){
		
		if ($hotel->proveedor==3) {

			$fotos = $this->getFotosDo($_POST['id_hotel'],true);

		}else{
			$fotos = HotelesFotos::model()->findAll('id_hotel='.$_POST['id_hotel']);
		}

		if ($fotos && count($fotos)>0) {
			echo '{"data":{"totalCount":'.count($fotos).',"hotelesFotos":'.CJSON::encode($fotos).'}}';
		}else{
			echo '{"data":{"totalCount":"0","hotelesFotos":[]}}';
		}
	}

	public function getFotosDo($id_hotel,$retorno){
		$hotel = Hoteles::model()->findByPk($id_hotel);

		$travelSolution = new TravelSolution;
		$clave_afiliado=$travelSolution->affiliateId;
		$idHotel = explode('/',$hotel->codigo);
		$hotelDoRequest = array();
		$hotelDo = $idHotel[0];
		$ip="MX";
		$currency="PE";
		$lenguage="esp";

		$request = "a=".$clave_afiliado."&ip=".$_SERVER["REMOTE_ADDR"]."&c=".$currency."&l=".$lenguage."&h=".$hotelDo;
		$response=$travelSolution->getHotelInformation($request);

		$responseDo = json_decode($response);
		$i=0;
		$_SESSION["informationHotelesTS"][$hotel->id_hotel] = $responseDo->Hotel;

		$fotos = $responseDo->Hotel->Galleries->Image;

		foreach ($fotos as $key => $value) {
			$fotos[$key]->foto = $value->URL;
		}

		if ($retorno==true) {
			return $fotos;
		}
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new HotelesFotos;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['HotelesFotos']))
		{
			$model->attributes=$_POST['HotelesFotos'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id_foto));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['HotelesFotos']))
		{
			$model->attributes=$_POST['HotelesFotos'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id_foto));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		if(Yii::app()->request->isPostRequest)
		{
			// we only allow deletion via POST request
			$this->loadModel($id)->delete();

			// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
			if(!isset($_GET['ajax']))
				$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
		}
		else
			throw new CHttpException(400,'Invalid request. Please do not repeat this request again.');
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
            $session=new CHttpSession;
            $session->open();		
            $criteria = new CDbCriteria();            

                $model=new HotelesFotos('search');
                $model->unsetAttributes();  // clear any default values

                if(isset($_GET['HotelesFotos']))
		{
                        $model->attributes=$_GET['HotelesFotos'];
			
			
                   	
                       if (!empty($model->id_foto)) $criteria->addCondition("id_foto = '".$model->id_foto."'");
                     
                    	
                       if (!empty($model->id_hotel)) $criteria->addCondition("id_hotel = '".$model->id_hotel."'");
                     
                    	
                       if (!empty($model->piedefoto)) $criteria->addCondition("piedefoto = '".$model->piedefoto."'");
                     
                    	
                       if (!empty($model->foto)) $criteria->addCondition("foto = '".$model->foto."'");
                     
                    	
                       if (!empty($model->log)) $criteria->addCondition("log = '".$model->log."'");
                     
                    	
                       if (!empty($model->principal)) $criteria->addCondition("principal = '".$model->principal."'");
                     
                    	
                       if (!empty($model->logotipo)) $criteria->addCondition("logotipo = '".$model->logotipo."'");
                     
                    	
                       if (!empty($model->boda)) $criteria->addCondition("boda = '".$model->boda."'");
                     
                    			
                    $session['HotelesFotos_records']=HotelesFotos::model()->findAll($criteria); 
		}
       

                $this->render('index',array(
			'model'=>$model,
		));

	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new HotelesFotos('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['HotelesFotos']))
			$model->attributes=$_GET['HotelesFotos'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer the ID of the model to be loaded
	 */
	public function loadModel($id)
	{
		$model=HotelesFotos::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param CModel the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='hoteles-fotos-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
        public function actionGenerateExcel()
	{
            $session=new CHttpSession;
            $session->open();		
            
             if(isset($session['HotelesFotos_records']))
               {
                $model=$session['HotelesFotos_records'];
               }
               else
                 $model = HotelesFotos::model()->findAll();

		
		Yii::app()->request->sendFile(date('YmdHis').'.xls',
			$this->renderPartial('excelReport', array(
				'model'=>$model
			), true)
		);
	}
        public function actionGeneratePdf() 
	{
           $session=new CHttpSession;
           $session->open();
		Yii::import('application.extensions.bootstrap.gii.*');
		require_once('bootstrap/tcpdf/tcpdf.php');
		require_once('bootstrap/tcpdf/config/lang/eng.php');

             if(isset($session['HotelesFotos_records']))
               {
                $model=$session['HotelesFotos_records'];
               }
               else
                 $model = HotelesFotos::model()->findAll();



		$html = $this->renderPartial('expenseGridtoReport', array(
			'model'=>$model
		), true);
		
		//die($html);
		
		$pdf = new TCPDF();
		$pdf->SetCreator(PDF_CREATOR);
		$pdf->SetAuthor(Yii::app()->name);
		$pdf->SetTitle('HotelesFotos Report');
		$pdf->SetSubject('HotelesFotos Report');
		//$pdf->SetKeywords('example, text, report');
		$pdf->SetHeaderData('', 0, "Report", '');
		$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, "Example Report by ".Yii::app()->name, "");
		$pdf->setHeaderFont(Array('helvetica', '', 8));
		$pdf->setFooterFont(Array('helvetica', '', 6));
		$pdf->SetMargins(15, 18, 15);
		$pdf->SetHeaderMargin(5);
		$pdf->SetFooterMargin(10);
		$pdf->SetAutoPageBreak(TRUE, 0);
		$pdf->SetFont('dejavusans', '', 7);
		$pdf->AddPage();
		$pdf->writeHTML($html, true, false, true, false, '');
		$pdf->LastPage();
		$pdf->Output("HotelesFotos_002.pdf", "I");
	}
}
