<?php

class UsuariosRestController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column1';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			array(
                'ext.starship.RestfullYii.filters.ERestFilter + 
                REST.GET, REST.PUT, REST.POST, REST.DELETE'
            ),
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow', 'actions'=>array('REST.GET', 'REST.PUT', 'REST.POST', 'REST.DELETE'),
				'users'=>array('@'),
			),
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array('index','view','getU'),
				'users'=>array('@'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array('create','update','GeneratePdf','GenerateExcel','delete'),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('admin'),
				'users'=>array('admin'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}

	public function actions()
	{
        return array('REST.'=>'ext.starship.RestfullYii.actions.ERestActionProvider',);
	}

	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model=new UsuariosRest;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['UsuariosRest']))
		{
			$model->attributes=$_POST['UsuariosRest'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id_usuario));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['UsuariosRest']))
		{
			$model->attributes=$_POST['UsuariosRest'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->id_usuario));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$model=Usuarios::model()->findByPk($id);

		$user=User::model()->findByPk($id);
		$estatus=$model->estatus;
		if($model && $user)
		{

			if($estatus=="A")
			{
				$user->status=0;
				$model->estatus="I";
				
			
			}else{
				$user->status=1;
				$model->estatus="A";
			}
			
			if(!$user->save())
			{
				echo json_encode($user->getErrors());
			}else{
				if(!$model->save())
				{
					echo json_encode($model->getErrors());
				}else{
					echo $model->estatus;
				}
			}


		}else{
			throw new CHttpException(404,'Error id no encontrado: '.$id);
		}
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
            $session=new CHttpSession;
            $session->open();		
            $criteria = new CDbCriteria();            

                $model=new UsuariosRest('search');
                $model->unsetAttributes();  // clear any default values

                if(isset($_GET['UsuariosRest']))
		{
                        $model->attributes=$_GET['UsuariosRest'];
			
			
                   	
                       if (!empty($model->id_usuario)) $criteria->addCondition("id_usuario = '".$model->id_usuario."'");
                     
                    	
                       if (!empty($model->nombre_usuario)) $criteria->addCondition("nombre_usuario = '".$model->nombre_usuario."'");
                     
                    	
                       if (!empty($model->email_usuario)) $criteria->addCondition("email_usuario = '".$model->email_usuario."'");
                     
                    	
                       if (!empty($model->clave_usuario)) $criteria->addCondition("clave_usuario = '".$model->clave_usuario."'");
                     
                    	
                       if (!empty($model->tipo_usuario)) $criteria->addCondition("tipo_usuario = '".$model->tipo_usuario."'");
                     
                    	
                       if (!empty($model->leng)) $criteria->addCondition("leng = '".$model->leng."'");
                     
                    	
                       if (!empty($model->id_agencia)) $criteria->addCondition("id_agencia = '".$model->id_agencia."'");
                     
                    	
                       if (!empty($model->id_hotel)) $criteria->addCondition("id_hotel = '".$model->id_hotel."'");
                     
                    	
                       if (!empty($model->ip_publica)) $criteria->addCondition("ip_publica = '".$model->ip_publica."'");
                     
                    	
                       if (!empty($model->log)) $criteria->addCondition("log = '".$model->log."'");
                     
                    	
                       if (!empty($model->foto)) $criteria->addCondition("foto = '".$model->foto."'");
                     
                    	
                       if (!empty($model->tema)) $criteria->addCondition("tema = '".$model->tema."'");
                     
                    	
                       if (!empty($model->plugin)) $criteria->addCondition("plugin = '".$model->plugin."'");
                     
                    	
                       if (!empty($model->activacion)) $criteria->addCondition("activacion = '".$model->activacion."'");
                     
                    	
                       if (!empty($model->estatus)) $criteria->addCondition("estatus = '".$model->estatus."'");
                     
                    	
                       if (!empty($model->fecha_nacimiento)) $criteria->addCondition("fecha_nacimiento = '".$model->fecha_nacimiento."'");
                     
                    	
                       if (!empty($model->aviso)) $criteria->addCondition("aviso = '".$model->aviso."'");
                     
                    			
                    $session['UsuariosRest_records']=UsuariosRest::model()->findAll($criteria); 
		}
       

                $this->render('index',array(
			'model'=>$model,
		));

	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new UsuariosRest('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['UsuariosRest']))
			$model->attributes=$_GET['UsuariosRest'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}


	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer the ID of the model to be loaded
	 */
	public function loadModel($id)
	{
		$model=UsuariosRest::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param CModel the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='usuarios-rest-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
        public function actionGenerateExcel()
	{
            $session=new CHttpSession;
            $session->open();		
            
             if(isset($session['UsuariosRest_records']))
               {
                $model=$session['UsuariosRest_records'];
               }
               else
                 $model = UsuariosRest::model()->findAll();

		
		Yii::app()->request->sendFile(date('YmdHis').'.xls',
			$this->renderPartial('excelReport', array(
				'model'=>$model
			), true)
		);
	}
        public function actionGeneratePdf() 
	{
           $session=new CHttpSession;
           $session->open();
		Yii::import('application.extensions.bootstrap.gii.*');
		require_once('bootstrap/tcpdf/tcpdf.php');
		require_once('bootstrap/tcpdf/config/lang/eng.php');

             if(isset($session['UsuariosRest_records']))
               {
                $model=$session['UsuariosRest_records'];
               }
               else
                 $model = UsuariosRest::model()->findAll();



		$html = $this->renderPartial('expenseGridtoReport', array(
			'model'=>$model
		), true);
		
		//die($html);
		
		$pdf = new TCPDF();
		$pdf->SetCreator(PDF_CREATOR);
		$pdf->SetAuthor(Yii::app()->name);
		$pdf->SetTitle('UsuariosRest Report');
		$pdf->SetSubject('UsuariosRest Report');
		//$pdf->SetKeywords('example, text, report');
		$pdf->SetHeaderData('', 0, "Report", '');
		$pdf->SetHeaderData(PDF_HEADER_LOGO, PDF_HEADER_LOGO_WIDTH, "Example Report by ".Yii::app()->name, "");
		$pdf->setHeaderFont(Array('helvetica', '', 8));
		$pdf->setFooterFont(Array('helvetica', '', 6));
		$pdf->SetMargins(15, 18, 15);
		$pdf->SetHeaderMargin(5);
		$pdf->SetFooterMargin(10);
		$pdf->SetAutoPageBreak(TRUE, 0);
		$pdf->SetFont('dejavusans', '', 7);
		$pdf->AddPage();
		$pdf->writeHTML($html, true, false, true, false, '');
		$pdf->LastPage();
		$pdf->Output("UsuariosRest_002.pdf", "I");
	}
}
