<?php

/**
 * This is the model class for table "{{catalogo_onboarding}}".
 *
 * The followings are the available columns in table '{{catalogo_onboarding}}':
 * @property integer $id
 * @property string $nombre
 * @property string $nivel
 * @property string $renderpartial
 * @property string $log
 *
 * The followings are the available model relations:
 * @property Onboarding[] $onboardings
 */
class CatalogoOnboarding extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return CatalogoOnboarding the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{catalogo_onboarding}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('nombre, nivel, log', 'required'),
			array('nombre, renderpartial', 'length', 'max'=>100),
			array('nivel', 'length', 'max'=>50),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, nombre, nivel, renderpartial, log', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'onboardings' => array(self::HAS_MANY, 'Onboarding', 'id_catalogo'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'nombre' => 'Nombre',
			'nivel' => 'Nivel',
			'renderpartial' => 'Renderpartial',
			'log' => 'Log',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('nombre',$this->nombre,true);
		$criteria->compare('nivel',$this->nivel,true);
		$criteria->compare('renderpartial',$this->renderpartial,true);
		$criteria->compare('log',$this->log,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}